Django Loupe v 0.1 — django-loupe 0.1 documentation

django-loupe 0.1 documentation

# Django Loupe v 0.1

- Table of Contents
- index
  next

# Django Loupe v 0.1

## About

Django Loupe provides an easy way to display zoomable, large images. The images may be hosted locally by uploading the original large image, or externally. Externally hosted images are referenced by their URL.

Zoomable images are displayed by making a tiled image pyramid. There are several methods and formats for making this pyramids. Django Loupe creates locally-hosted tiles in the Deep Zoom format developed by Microsoft using the open source VIPS library.

The OpenSeadragon JavaScript library displays the locally- or externally-hosted images.

## Contents

- Getting Started
  - Install
  - Upload an image
  - Enter an externally hosted image
  - Serving an image
  - Using remote storage
- Reference
  - Settings